## segway 1.0.0.dev-r5498 run 9d9028be5cac11e0b5e70019b9e1892e at 2011-04-01 15:08:46.944731
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkTriangulate -cppCommandOptions "-DCARD_SEG=4 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -outputTriangulatedFile identifydir/triangulation/segway.str.4.1.trifile -strFile traindir/segway.str -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkViterbi -base 3 -cliqueTableNormalize 0.0 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.params -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile identifydir/log/jt_info.txt -lst 100000 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -of1 identifydir/observations/int.list -of2 identifydir/observations/float32.list -pVitRegexFilter ^seg$ -pVitValsFile - -strFile traindir/segway.str -triFile identifydir/triangulation/segway.str.4.1.trifile -verbosity 0
