## segway 1.0.0.dev-r5498 run 9d5a5f2a5c1d11e0a54e0019b9e1892e at 2011-03-31 22:05:08.556753

"/net/noble/vol2/home/mmh1/arch/Linux/RHEL5/x86_64/bin/segway" "--clobber" "--num-labels=4" "train" "data/GL000145.h3k27k36me3.genomedata" "traindir"
