## segway 1.0.0.dev-r5498 run 9d9028be5cac11e0b5e70019b9e1892e at 2011-04-01 15:08:46.944731

"/net/noble/vol2/home/mmh1/arch/Linux/RHEL5/x86_64/bin/segway" "identify" "data/GL000145.h3k27k36me3.genomedata" "traindir" "identifydir"
