## segway 1.0.0.dev-r5498 run 9d5a5f2a5c1d11e0a54e0019b9e1892e at 2011-03-31 22:05:08.556753
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkTriangulate -cppCommandOptions "-DCARD_SEG=4 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -outputTriangulatedFile traindir/triangulation/segway.str.4.1.trifile -strFile traindir/segway.str -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.0 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.0 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.1 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.0 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.1 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.2 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.1 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.2 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.3 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.2 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.3 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.3 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.4 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.5 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.4 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.5 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.6 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.5 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.6 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.7 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.6 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.7 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.8 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.7 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.8 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.9 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.8 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.9 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.10 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.9 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.10 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.11 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.10 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.11 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.12 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.11 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.12 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.13 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.12 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.13 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.14 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.13 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.14 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.15 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.14 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.15 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.16 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.15 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.16 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.17 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.16 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.17 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.18 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.17 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.18 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.19 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.18 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.19 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.20 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.19 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.20 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.21 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.20 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.21 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.22 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.21 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.22 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.23 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.22 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.23 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.24 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.23 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.24 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.25 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.24 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.25 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.26 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.25 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.26 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.27 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.26 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.27 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.28 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.27 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.28 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.29 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.28 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.29 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.30 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.29 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.30 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.31 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.30 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.31 -DCARD_FRAMEINDEX=2000000 -DSEGTRANSITION_WEIGHT_SCALE=1.0 -DCARD_SUBSEG=1" -deterministicChildrenStore F -dirichletPriors T -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -lldp 0.001 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -storeAccFile traindir/accumulators/acc.0.0.bin -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng 0 -verbosity 0
/net/noble/vol1/software/modules-sw/gmtk/20091016/Linux/RHEL5/x86_64//bin/gmtkEMtrainNew -base 3 -componentCache F -cppCommandOptions "-DCARD_SEG=4 -DOUTPUT_PARAMS_FILENAME=traindir/params/params.0.params.32 -DINPUT_PARAMS_FILENAME=traindir/params/params.0.params.31 -DCARD_FRAMEINDEX=2000000 -DCARD_SUBSEG=1 -DSEGTRANSITION_WEIGHT_SCALE=1.0" -deterministicChildrenStore F -fmt1 binary -fmt2 binary -hashLoadFactor 0.98 -inputMasterFile traindir/params/input.master -island T -iswp1 F -iswp2 F -jtFile traindir/log/jt_info.txt -llStoreFile traindir/likelihood/likelihood.ll -lldp 0.001 -loadAccFile traindir/accumulators/acc.0.@D.bin -loadAccRange 0:0 -lst 100000 -maxEmIters 1 -nf1 0 -nf2 2 -ni1 2 -ni2 0 -objsNotToTrain traindir/auxiliary/dont_train.list -of1 traindir/observations/int.list -of2 traindir/observations/float32.list -outputMasterFile traindir/params/output.master -strFile traindir/segway.str -triFile traindir/triangulation/segway.str.4.1.trifile -trrng nil -verbosity 0
